===============================
dwlver
===============================

.. image:: https://img.shields.io/pypi/v/dwlver.svg
        :target: https://pypi.python.org/pypi/dwlver

.. image:: https://img.shields.io/travis/digwanderlust/dwlver.svg
        :target: https://travis-ci.org/digwanderlust/dwlver

.. image:: https://readthedocs.io/projects/dwlver/badge/?version=latest
        :target: https://readthedocs.io/projects/dwlver/?badge=latest
        :alt: Documentation Status

.. image:: https://requires.io/github/digwanderlust/dwlver/requirements.svg?branch=master
        :target: https://requires.io/github/digwanderlust/dwlver/requirements?branch=master
        :alt: Dependencies


version testing

* Free software: BSD license
* Documentation: https://dwlver.readthedocs.io.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`digwanderlust/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
